A mirror for witches : in which is reflected the life, machinations, and death… | Project Gutenberg
Description: Free kindle book and epub digitized and proofread by volunteers.
Keywords: ebook, ebooks, free ebooks, free books, book, books, audio books

# A mirror for witches : in which is reflected the life, machinations, and death…

## Read now or download (free!)

| Choose how to read this book | Url | Size |  |  |
--- | --- | --- | --- | --- | --- | ---
| Read online (web) | https://www.gutenberg.org/ebooks/75212.html.images | 297 kB |  |  |
| EPUB3 (E-readers incl. Send-to-Kindle) | https://www.gutenberg.org/ebooks/75212.epub3.images | 1.7 MB |  |  |
| EPUB (older E-readers) | https://www.gutenberg.org/ebooks/75212.epub.images | 1.7 MB |  |  |
| EPUB (no images, older E-readers) | https://www.gutenberg.org/ebooks/75212.epub.noimages | 279 kB |  |  |
| Kindle | https://www.gutenberg.org/ebooks/75212.kf8.images | 2.0 MB |  |  |
| older Kindles | https://www.gutenberg.org/ebooks/75212.kindle.images | 2.0 MB |  |  |
| Plain Text UTF-8 | https://www.gutenberg.org/ebooks/75212.txt.utf-8 | 257 kB |  |  |
| Download HTML (zip) | https://www.gutenberg.org/cache/epub/75212/pg75212-h.zip | 1.9 MB |  |  |
| There may be more files related to this item.

## Similar Books

Readers also downloaded…

## About this eBook

Author | Forbes, Esther, 1891-1967
Illustrator | Gibbings, Robert, 1889-1958
Title | A mirror for witches : in which is reflected the life, machinations, and death of famous Doll Bilby, who, with a more than feminine perversity, preferred a demon to a mortal lover; here is also told how and why a righteous and most awfull judgement befell her, destroying both corporeal body and immortal soul
Original Publication | Boston: Houghton Mifflin Company, 1928.
Note | Wikipedia page on this work: https://en.wikipedia.org/wiki/A_Mirror_for_Witches
Credits | Bob Taylor, deaurider and the Online Distributed Proofreading Team at https://www.pgdp.net (This file was produced from images generously made available by The Internet Archive)
Language | English
LoC Class | PS: Language and Literatures: American and Canadian literature
Subject | Historical fiction
Subject | Witches -- Fiction
Subject | Paranormal fiction
Subject | Trials (Witchcraft) -- Fiction
Subject | Salem (Mass.) -- History -- Colonial period, ca. 1600-1775 -- Fiction
Subject | Women -- Massachusetts -- Salem -- Fiction
Category | Text
EBook-No. | 75212
Release Date | Jan 26, 2025
Copyright Status | Public domain in the USA.
Downloads | 1079 downloads in the last 30 days.
Project Gutenberg eBooks are always free!